==> qmmp-0.10.10.tar.bz2: qmmp-0.10.10/src/plugins/Input/wavpack/translations/wavpack_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="45"/>
        <source>WavPack Plugin</source>
        <translation>Πρόσθετο WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="47"/>
        <source>WavPack Files</source>
        <translation>Αρχεία WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="161"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Σχετικά με το πρόσθετο ήχου WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="162"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp πρόσθετο ήχου WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="163"/>
        <source>WavPack library version:</source>
        <translation>Έκδοση βιβλιοθήκης WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="165"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="70"/>
        <source>Length</source>
        <translation>Διάρκεια</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Sample rate</source>
        <translation>Ρυθμός δειγματοληψίας</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="72"/>
        <source>Channels</source>
        <translation>Κανάλια</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Bitrate</source>
        <translation>Ρυθμός bit</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="75"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="76"/>
        <source>Ratio</source>
        <translation>Αναλογία</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="77"/>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.14.tar.bz2: qmmp-0.12.14/src/plugins/Input/wavpack/translations/wavpack_plugin_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="38"/>
        <source>WavPack Plugin</source>
        <translation>Πρόσθετο WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="40"/>
        <source>WavPack Files</source>
        <translation>Αρχεία WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="176"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Σχετικά με το πρόσθετο ήχου WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="177"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Qmmp πρόσθετο ήχου WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="178"/>
        <source>WavPack library version:</source>
        <translation>Έκδοση βιβλιοθήκης WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="180"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>WavPackMetaDataModel</name>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="73"/>
        <source>Ratio</source>
        <translation>Αναλογία</translation>
    </message>
    <message>
        <location filename="../wavpackmetadatamodel.cpp" line="74"/>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
</context>
</TS>
